@@ -111,11 +111,9 @@ cell_properties_set_table (GtkhtmlEditor *editor,
 {
 	GtkHTML *html;
 	HTMLObject *parent;
-	HTMLTableCell *cell;
 	HTMLTableCell *iter;
 
 	html = gtkhtml_editor_get_html (editor);
-	cell = HTML_TABLE_CELL (editor->priv->cell_object);
 	parent = editor->priv->cell_parent;
 
 	iter = html_engine_get_table_cell (html->engine);
@@ -253,7 +251,7 @@ cell_properties_set_horizontal_alignment_cb (GtkhtmlEditor *editor,
 	active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 	align = HTML_HALIGN_LEFT + (HTMLHAlignType) active;
 
-	html_engine_table_cell_set_halign (html->engine, cell, active);
+	html_engine_table_cell_set_halign (html->engine, cell, align);
 }
 
 static void
@@ -784,12 +782,8 @@ gtkhtml_editor_image_properties_show_window_cb (GtkWidget *window))
 		|| html_object_get_data (parent, "template_image") == NULL)
 		&& image->image_ptr->url != NULL) {
 
-		gchar *filename;
-
-		filename = gtk_html_filename_from_uri (image->image_ptr->url);
-		gtk_file_chooser_set_filename (
-			GTK_FILE_CHOOSER (widget), filename);
-		g_free (filename);
+		gtk_file_chooser_set_uri (
+			GTK_FILE_CHOOSER (widget), image->image_ptr->url);
 	} else
 		gtk_file_chooser_unselect_all (GTK_FILE_CHOOSER (widget));
 
